==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/module_center/module_center_module.hermeshsi.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   module_center_module.hermeshsi.lang.inc.php 2020-04-03
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2019 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/
declare(strict_types=1);

$t_language_text_section_content_array = [
    'hermeshsi_api_access_credentials'            => 'API-Zugangsdaten',
    'hermeshsi_authentication_failed'             => 'API-Zugang nicht möglich, bitte Zugangsdaten prüfen',
    'hermeshsi_button_submit'                     => 'Speichern',
    'hermeshsi_cannot_retrieve_label'             => 'Beim Abruf des Labels ist ein Fehler aufgetreten.',
    'hermeshsi_cod_amount'                        => 'Nachnahmebetrag',
    'hermeshsi_configuration'                     => 'Konfiguration',
    'hermeshsi_create_order_title'                => 'Versandauftrag anlegen (Hermes HSI)',
    'hermeshsi_created_shipment_order'            => 'Hermes-Versandauftrag angelegt',
    'hermeshsi_credentials_invalid'               => 'Mit den angegebenen Zugangsdaten konnte kein Zugang zur HSI-Schnittstelle hergestellt werden.',
    'hermeshsi_description'                       => 'Versandlabelerstellung Hermes (HSI)',
    'hermeshsi_direct_download'                   => 'Sofortdownload verwenden',
    'hermeshsi_direct_download_on'                => 'erzeugtes Label automatisch herunterladen/anzeigen',
    'hermeshsi_direct_download_off'               => 'erzeugtes Label manuell abrufen',
    'hermeshsi_existing_shipmentorders'           => 'Erzeugte Versandaufträge',
    'hermeshsi_label'                             => 'Versandlabel',
    'hermeshsi_label_download_method'             => 'Methode für Labeldownload',
    'hermeshsi_label_orderstatusafterprint'       => 'Bestellstatus nach Abruf des Labels',
    'hermeshsi_label_orderstatusaftersave'        => 'Bestellstatus nach Speichern des Versandauftrags',
    'hermeshsi_label_parcelservice'               => 'Paketdienst',
    'hermeshsi_label_printed'                     => 'Hermes-Versandlabel erzeugt',
    'hermeshsi_label_testmode'                    => 'Testmodus',
    'hermeshsi_labelbutton'                       => 'Label abrufen',
    'hermeshsi_labeldownloadmethod_attachment'    => 'als Datei-Download',
    'hermeshsi_labeldownloadmethod_inline'        => 'Inline in neuem Tab/Fenster',
    'hermeshsi_ordersoverview_hermeshsi_label'    => 'Hermes-Label (HSI)',
    'hermeshsi_orderstatus_nochange'              => '–– nicht ändern ––',
    'hermeshsi_original_value'                    => 'Wert gekürzt, Original',
    'hermeshsi_parcel'                            => 'Paket',
    'hermeshsi_parcel_class'                      => 'Paketklasse',
    'hermeshsi_parcel_class_l'                    => 'Paketklasse L',
    'hermeshsi_parcel_class_m'                    => 'Paketklasse M',
    'hermeshsi_parcel_class_none'                 => 'keine Angabe (Berechnung aus Abmessungen)',
    'hermeshsi_parcel_class_s'                    => 'Paketklasse S',
    'hermeshsi_parcel_class_xl'                   => 'Paketklasse XL',
    'hermeshsi_parcel_class_xs'                   => 'Paketklasse XS',
    'hermeshsi_parcel_depth'                      => 'Tiefe des Pakets (mm)',
    'hermeshsi_parcel_height'                     => 'Höhe des Pakets (mm)',
    'hermeshsi_parcel_presets'                    => 'Vorgabe-Abmessungen',
    'hermeshsi_parcel_weight'                     => 'Gewicht des Pakets (g)',
    'hermeshsi_parcel_weight_mode'                => 'Vorgabe Paketgewicht',
    'hermeshsi_parcel_width'                      => 'Weite des Pakets (mm)',
    'hermeshsi_parcelservice_donotuse'            => '–– Sendungsverfolgung nicht verwenden ––',
    'hermeshsi_parcelweightmode_addpackingweight' => 'Verpackungsgewicht berücksichtigen',
    'hermeshsi_parcelweightmode_none'             => 'keine',
    'hermeshsi_parcelweightmode_productsweight'   => 'nur Artikelgewicht berücksichtigen',
    'hermeshsi_password'                          => 'Passwort',
    'hermeshsi_preset'                            => 'Vorgabe',
    'hermeshsi_preset_depth'                      => 'Tiefe (mm)',
    'hermeshsi_preset_height'                     => 'Höhe (mm)',
    'hermeshsi_preset_width'                      => 'Weite (mm)',
    'hermeshsi_receiver'                          => 'Empfänger',
    'hermeshsi_receiver_addressaddition'          => 'Adresszusatz',
    'hermeshsi_receiver_addressaddition2'         => 'Adresszusatz 2',
    'hermeshsi_receiver_addressaddition3'         => 'Adresszusatz 3',
    'hermeshsi_receiver_contact_tooltip'          => 'Zusätzliche Kontaktmöglichkeit wird z.B. für Versand nach Dänemark und Schweden benötigt.',
    'hermeshsi_receiver_contactmail'              => 'Kontakt E-Mail',
    'hermeshsi_receiver_contactmobile'            => 'Kontakt Mobiltelefon',
    'hermeshsi_receiver_contactphone'             => 'Kontakt Telefon',
    'hermeshsi_receiver_countrycode'              => 'Land',
    'hermeshsi_receiver_firstname'                => 'Vorname',
    'hermeshsi_receiver_gender'                   => 'Geschlecht',
    'hermeshsi_receiver_gender_m'                 => 'männlich',
    'hermeshsi_receiver_gender_o'                 => 'divers/keine Angabe',
    'hermeshsi_receiver_gender_w'                 => 'weiblich',
    'hermeshsi_receiver_housenumber'              => 'Hausnummer',
    'hermeshsi_receiver_housenumber_tooltip'      => 'Angabe kann auch bei Straße erfolgen',
    'hermeshsi_receiver_lastname'                 => 'Nachname',
    'hermeshsi_receiver_middlename'               => 'Mittelname',
    'hermeshsi_receiver_street'                   => 'Straße',
    'hermeshsi_receiver_title'                    => 'Titel',
    'hermeshsi_receiver_town'                     => 'Stadt',
    'hermeshsi_receiver_zipcode'                  => 'Postleitzahl',
    'hermeshsi_request_access'                    => 'Zugang einrichten',
    'hermeshsi_save_order'                        => 'Auftrag speichern',
    'hermeshsi_sender'                            => 'Absender',
    'hermeshsi_sender_addressaddition'            => 'Adresszusatz',
    'hermeshsi_sender_addressaddition2'           => 'Adresszusatz 2',
    'hermeshsi_sender_addressaddition3'           => 'Adresszusatz 3',
    'hermeshsi_sender_countrycode'                => 'Land',
    'hermeshsi_sender_firstname'                  => 'Vorname',
    'hermeshsi_sender_gender'                     => 'Geschlecht',
    'hermeshsi_sender_gender_m'                   => 'männlich',
    'hermeshsi_sender_gender_o'                   => 'divers/keine Angabe',
    'hermeshsi_sender_gender_w'                   => 'weiblich',
    'hermeshsi_sender_housenumber'                => 'Hausnummer',
    'hermeshsi_sender_lastname'                   => 'Nachname',
    'hermeshsi_sender_middlename'                 => 'Mittelname',
    'hermeshsi_sender_street'                     => 'Straße',
    'hermeshsi_sender_title'                      => 'Titel',
    'hermeshsi_sender_town'                       => 'Stadt',
    'hermeshsi_sender_zipcode'                    => 'Postleitzahl',
    'hermeshsi_services'                          => 'Optionen',
    'hermeshsi_shipment_actual_order_state'       => 'Status',
    'hermeshsi_shipment_create_date'              => 'Erstellungszeit',
    'hermeshsi_shipment_id'                       => 'Sendungsnummer',
    'hermeshsi_shipment_order_number'             => 'Auftragsnummer',
    'hermeshsi_shipmentorder_status_unknown'      => 'Status unbekannt/nicht abrufbar',
    'hermeshsi_status_ARCHIVED'                   => 'archiviert',
    'hermeshsi_status_CREATED'                    => 'erzeugt',
    'hermeshsi_status_DELETED'                    => 'gelöscht',
    'hermeshsi_status_FAILED'                     => 'fehlgeschlagen',
    'hermeshsi_status_PLACED'                     => 'Label erzeugt',
    'hermeshsi_testmode_off'                      => 'Produktivmodus (Testmodus deaktiviert)',
    'hermeshsi_testmode_on'                       => 'Testmodus (nur für Entwicklung/Fehleranalyse!)',
    'hermeshsi_title'                             => 'Hermes (HSI)',
    'hermeshsi_userid'                            => 'Benutzer-ID',
    'hermeshsi_username'                          => 'Benutzername',
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/module_center/module_center_module.hermeshsi.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   module_center_module.hermeshsi.lang.inc.php 2021-03-30
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2019 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/
declare(strict_types=1);

$t_language_text_section_content_array = [
    'hermeshsi_api_access_credentials'            => 'API-Zugangsdaten',
    'hermeshsi_authentication_failed'             => 'API-Zugang nicht möglich, bitte Zugangsdaten prüfen',
    'hermeshsi_button_submit'                     => 'Speichern',
    'hermeshsi_cannot_retrieve_label'             => 'Beim Abruf des Labels ist ein Fehler aufgetreten.',
    'hermeshsi_cod_amount'                        => 'Nachnahmebetrag',
    'hermeshsi_configuration'                     => 'Konfiguration',
    'hermeshsi_create_order_title'                => 'Versandauftrag anlegen (Hermes HSI)',
    'hermeshsi_created_shipment_order'            => 'Hermes-Versandauftrag angelegt',
    'hermeshsi_credentials_invalid'               => 'Mit den angegebenen Zugangsdaten konnte kein Zugang zur HSI-Schnittstelle hergestellt werden.',
    'hermeshsi_description'                       => 'Versandlabelerstellung Hermes (HSI)',
    'hermeshsi_direct_download'                   => 'Sofortdownload verwenden',
    'hermeshsi_direct_download_on'                => 'erzeugtes Label automatisch herunterladen/anzeigen',
    'hermeshsi_direct_download_off'               => 'erzeugtes Label manuell abrufen',
    'hermeshsi_existing_shipmentorders'           => 'Erzeugte Versandaufträge',
    'hermeshsi_label'                             => 'Versandlabel',
    'hermeshsi_label_download_method'             => 'Methode für Labeldownload',
    'hermeshsi_label_orderstatusafterprint'       => 'Bestellstatus nach Abruf des Labels',
    'hermeshsi_label_orderstatusaftersave'        => 'Bestellstatus nach Speichern des Versandauftrags',
    'hermeshsi_label_parcelservice'               => 'Paketdienst',
    'hermeshsi_label_printed'                     => 'Hermes-Versandlabel erzeugt',
    'hermeshsi_label_testmode'                    => 'Testmodus',
    'hermeshsi_labelbutton'                       => 'Label abrufen',
    'hermeshsi_labeldownloadmethod_attachment'    => 'als Datei-Download',
    'hermeshsi_labeldownloadmethod_inline'        => 'Inline in neuem Tab/Fenster',
    'hermeshsi_notification_email'                => 'E-Mail f. Benachrichtigung bei NN',
    'hermeshsi_ordersoverview_hermeshsi_label'    => 'Hermes-Label (HSI)',
    'hermeshsi_orderstatus_nochange'              => '–– nicht ändern ––',
    'hermeshsi_original_value'                    => 'Wert gekürzt, Original',
    'hermeshsi_parcel'                            => 'Paket',
    'hermeshsi_parcel_class'                      => 'Paketklasse',
    'hermeshsi_parcel_class_l'                    => 'Paketklasse L',
    'hermeshsi_parcel_class_m'                    => 'Paketklasse M',
    'hermeshsi_parcel_class_none'                 => 'keine Angabe (Berechnung aus Abmessungen)',
    'hermeshsi_parcel_class_s'                    => 'Paketklasse S',
    'hermeshsi_parcel_class_xl'                   => 'Paketklasse XL',
    'hermeshsi_parcel_class_xs'                   => 'Paketklasse XS',
    'hermeshsi_parcel_depth'                      => 'Tiefe des Pakets (mm)',
    'hermeshsi_parcel_height'                     => 'Höhe des Pakets (mm)',
    'hermeshsi_parcel_presets'                    => 'Vorgabe-Abmessungen',
    'hermeshsi_parcel_weight'                     => 'Gewicht des Pakets (g)',
    'hermeshsi_parcel_weight_mode'                => 'Vorgabe Paketgewicht',
    'hermeshsi_parcel_width'                      => 'Weite des Pakets (mm)',
    'hermeshsi_parcelservice_donotuse'            => '–– Sendungsverfolgung nicht verwenden ––',
    'hermeshsi_parcelweightmode_addpackingweight' => 'Verpackungsgewicht berücksichtigen',
    'hermeshsi_parcelweightmode_none'             => 'keine',
    'hermeshsi_parcelweightmode_productsweight'   => 'nur Artikelgewicht berücksichtigen',
    'hermeshsi_password'                          => 'Passwort',
    'hermeshsi_preset'                            => 'Vorgabe',
    'hermeshsi_preset_depth'                      => 'Tiefe (mm)',
    'hermeshsi_preset_height'                     => 'Höhe (mm)',
    'hermeshsi_preset_width'                      => 'Weite (mm)',
    'hermeshsi_receiver'                          => 'Empfänger',
    'hermeshsi_receiver_addressaddition'          => 'Adresszusatz',
    'hermeshsi_receiver_addressaddition2'         => 'Adresszusatz 2',
    'hermeshsi_receiver_addressaddition3'         => 'Adresszusatz 3',
    'hermeshsi_receiver_contact_tooltip'          => 'Zusätzliche Kontaktmöglichkeit wird z.B. für Versand nach Dänemark und Schweden benötigt.',
    'hermeshsi_receiver_contactmail'              => 'Kontakt E-Mail',
    'hermeshsi_receiver_contactmobile'            => 'Kontakt Mobiltelefon',
    'hermeshsi_receiver_contactphone'             => 'Kontakt Telefon',
    'hermeshsi_receiver_countrycode'              => 'Land',
    'hermeshsi_receiver_firstname'                => 'Vorname',
    'hermeshsi_receiver_gender'                   => 'Geschlecht',
    'hermeshsi_receiver_gender_m'                 => 'männlich',
    'hermeshsi_receiver_gender_o'                 => 'divers/keine Angabe',
    'hermeshsi_receiver_gender_w'                 => 'weiblich',
    'hermeshsi_receiver_housenumber'              => 'Hausnummer',
    'hermeshsi_receiver_housenumber_tooltip'      => 'Angabe kann auch bei Straße erfolgen',
    'hermeshsi_receiver_lastname'                 => 'Nachname',
    'hermeshsi_receiver_middlename'               => 'Mittelname',
    'hermeshsi_receiver_street'                   => 'Straße',
    'hermeshsi_receiver_title'                    => 'Titel',
    'hermeshsi_receiver_town'                     => 'Stadt',
    'hermeshsi_receiver_zipcode'                  => 'Postleitzahl',
    'hermeshsi_required_input'                    => 'Pflichtangabe',
    'hermeshsi_request_access'                    => 'Zugang einrichten',
    'hermeshsi_save_order'                        => 'Auftrag speichern',
    'hermeshsi_sender'                            => 'Absender',
    'hermeshsi_sender_addressaddition'            => 'Adresszusatz',
    'hermeshsi_sender_addressaddition2'           => 'Adresszusatz 2',
    'hermeshsi_sender_addressaddition3'           => 'Adresszusatz 3',
    'hermeshsi_sender_countrycode'                => 'Land',
    'hermeshsi_sender_firstname'                  => 'Vorname',
    'hermeshsi_sender_gender'                     => 'Geschlecht',
    'hermeshsi_sender_gender_m'                   => 'männlich',
    'hermeshsi_sender_gender_o'                   => 'divers/keine Angabe',
    'hermeshsi_sender_gender_w'                   => 'weiblich',
    'hermeshsi_sender_housenumber'                => 'Hausnummer',
    'hermeshsi_sender_lastname'                   => 'Nachname',
    'hermeshsi_sender_middlename'                 => 'Mittelname',
    'hermeshsi_sender_street'                     => 'Straße',
    'hermeshsi_sender_title'                      => 'Titel',
    'hermeshsi_sender_town'                       => 'Stadt',
    'hermeshsi_sender_zipcode'                    => 'Postleitzahl',
    'hermeshsi_services'                          => 'Optionen',
    'hermeshsi_shipment_actual_order_state'       => 'Status',
    'hermeshsi_shipment_create_date'              => 'Erstellungszeit',
    'hermeshsi_shipment_id'                       => 'Sendungsnummer',
    'hermeshsi_shipment_order_number'             => 'Auftragsnummer',
    'hermeshsi_shipmentorder_status_unknown'      => 'Status unbekannt/nicht abrufbar',
    'hermeshsi_status_ARCHIVED'                   => 'archiviert',
    'hermeshsi_status_CREATED'                    => 'Auftrag erzeugt',
    'hermeshsi_status_DELETED'                    => 'gelöscht',
    'hermeshsi_status_FAILED'                     => 'fehlgeschlagen',
    'hermeshsi_status_PLACED'                     => 'Label erzeugt',
    'hermeshsi_testmode_off'                      => 'Produktivmodus (Testmodus deaktiviert)',
    'hermeshsi_testmode_on'                       => 'Testmodus (nur für Entwicklung/Fehleranalyse!)',
    'hermeshsi_title'                             => 'Hermes (HSI)',
    'hermeshsi_userid'                            => 'Benutzer-ID',
    'hermeshsi_username'                          => 'Benutzername',
];
